/* -----------------------------------------------------------------------------
 *
 * (c) The GHC Team 1998-2005
 *
 * Interval timer for profiling and pre-emptive scheduling.
 *
 * ---------------------------------------------------------------------------*/

#ifndef ITIMER_H
#define ITIMER_H

RTS_PRIVATE lnat getourtimeofday ( void );

#endif /* ITIMER_H */
